@@ -334,7 +334,7 @@ gkm_keyring_manager_delete_keyring (GKMKeyringManager *self,
 
 /*   if (!gtk_tree_row_reference_valid (data->row)) */
 /*     { */
-/*       g_warning (_("A row disappeared while we were waiting for it to be locked...")); */
+/*       g_warning ("A row disappeared while we were waiting for it to be locked..."); */
 
 /*       return; */
 /*     } */
@@ -408,7 +408,7 @@ gkm_keyring_manager_delete_keyring (GKMKeyringManager *self,
 /* { */
 /*   if (result != GNOME_KEYRING_RESULT_OK)  */
 /*     { */
-/*       g_warning (_("Failed to get keyring info.")); */
+/*       g_warning ("Failed to get keyring info."); */
 
 /*       return; */
 /*     } */
@@ -519,7 +519,7 @@ gkm_keyring_manager_delete_keyring (GKMKeyringManager *self,
 /* { */
 /*  if (result != GNOME_KEYRING_RESULT_OK)  */
 /*     { */
-/*       g_warning (_("Failed to get keyring info.")); */
+/*       g_warning ("Failed to get keyring info."); */
 
 /*       return; */
 /*     } */
@@ -603,7 +603,7 @@ gkm_keyring_manager_delete_keyring (GKMKeyringManager *self,
 /*   if (result != GNOME_KEYRING_RESULT_OK) */
 /*     { */
 /*       /\* FIXME: tell the user about this. *\/ */
-/*       g_warning (_("Failed set the default keyring.")); */
+/*       g_warning ("Failed set the default keyring."); */
 
 /*       return; */
 /*     } */
@@ -747,7 +747,7 @@ get_default_keyring_callback (GnomeKeyringResult  result,
 
   if (result != GNOME_KEYRING_RESULT_OK)
     {
-      g_warning (_("Failed get the default keyring."));
+      g_warning ("Failed get the default keyring.");
 
       return;
     }
@@ -764,7 +764,7 @@ get_default_keyring_callback (GnomeKeyringResult  result,
         }
       else
         {
-          g_warning (_("The default keyring is not in the list store!"));
+          g_warning ("The default keyring is not in the list store!");
         }
 
       g_free (manager->priv->default_keyring);
@@ -821,14 +821,14 @@ update_keyring_info_worker_callback (GnomeKeyringResult         result,
   
   if (result != GNOME_KEYRING_RESULT_OK) 
     {
-      g_warning (_("Failed to get keyring info."));
+      g_warning ("Failed to get keyring info.");
 
       return;
     }
 
   if (!gtk_tree_row_reference_valid (data->row))
     {
-      g_warning (_("A row disapeared while we were waiting for the data..."));
+      g_warning ("A row disappeared while we were waiting for the data...");
 
       return;
     }
